@@ -4,7 +4,7 @@
  * control the pace of reading. 
  *****************************************************************************
  * Copyright (C) 1999, 2000 VideoLAN
- * $Id: input_ext-intf.h,v 1.20 2001/02/16 06:37:09 sam Exp $
+ * $Id: input_ext-intf.h,v 1.34 2001/04/20 05:40:03 stef Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *
@@ -33,6 +33,8 @@
 #define REQUESTED_LPCM         3
 #define REQUESTED_NOAUDIO    255
 
+#define OFFSETTOTIME_MAX_SIZE       10
+
 /*****************************************************************************
  * es_descriptor_t: elementary stream descriptor
  *****************************************************************************
@@ -50,6 +52,12 @@ typedef struct es_descriptor_s
     boolean_t               b_audio;      /* is the stream an audio stream that
                                            * will need to be discarded with
                                            * fast forward and slow motion ?  */
+    u8                      i_cat;        /* stream category: video, audio,
+                                           * spu, other */
+
+    char                    psz_desc[20]; /* description of ES: audio language
+                                           * for instance ; NULL if not
+                                           *  available */
 
     /* Demultiplexer information */
     void *                  p_demux_data;
@@ -89,6 +97,12 @@ typedef struct es_descriptor_s
 #define LPCM_AUDIO_ES       0x83
 #define UNKNOWN_ES          0xFF
 
+/* ES Categories to be used by interface plugins */
+#define VIDEO_ES        0x00
+#define AUDIO_ES        0x01
+#define SPU_ES          0x02
+#define NAV_ES          0x03
+#define UNKNOWN_ES      0xFF
 /*****************************************************************************
  * pgrm_descriptor_t
  *****************************************************************************
@@ -131,6 +145,36 @@ typedef struct pgrm_descriptor_s
 #define SYNCHRO_START       1
 #define SYNCHRO_REINIT      2
 
+/*****************************************************************************
+ * input_area_t
+ *****************************************************************************
+ * Attributes for current area (title for DVD)
+ *****************************************************************************/
+typedef struct input_area_s
+{
+    /* selected area attributes */
+    int                     i_id;        /* identificator for area */
+    off_t                   i_start;     /* start offset of area */
+    off_t                   i_size;      /* total size of the area
+                                          * (in arbitrary units) */
+
+    /* navigation parameters */
+    off_t                   i_tell;      /* actual location in the area
+                                          * (in arbitrary units) */
+    off_t                   i_seek;      /* next requested location
+                                          * (changed by the interface thread */
+
+    /* area subdivision */
+    int                     i_part_nb;   /* number of parts (chapter for DVD)*/
+    int                     i_part;      /* currently selected part */
+
+    int                     i_angle_nb;  /* number of angles/title units */
+    int                     i_angle;
+
+    /* offset to plugin related data */
+    off_t                   i_plugin_data;
+} input_area_t;
+
 /*****************************************************************************
  * stream_descriptor_t
  *****************************************************************************
@@ -140,19 +184,24 @@ typedef struct pgrm_descriptor_s
 typedef struct stream_descriptor_s
 {
     u16                     i_stream_id;                        /* stream id */
+    boolean_t               b_changed;    /* if stream has been changed,
+                                             we have to inform the interface */
     vlc_mutex_t             stream_lock;  /* to be taken every time you read
                                            * or modify stream, pgrm or es    */
 
     /* Input method data */
+    int                     i_method;       /* input method for stream: file,
+                                               disc or network */
     boolean_t               b_pace_control;    /* can we read when we want ? */
     boolean_t               b_seekable;               /* can we do lseek() ? */
+
     /* if (b_seekable) : */
-    off_t                   i_size;                  /* total size of the file
-                                                      * (in arbitrary units) */
-    off_t                   i_tell;             /* actual location in the file
-                                                 * (in arbitrary units) */
-    off_t                   i_seek;         /* next requested location (changed
-                                             * by the interface thread */
+    int                     i_area_nb;
+    input_area_t **         pp_areas;      /* list of areas in stream == offset
+                                            * interval with own properties */
+    input_area_t *          p_selected_area;
+    u32                     i_mux_rate; /* the rate we read the stream (in
+                                         * units of 50 bytes/s) ; 0 if undef */
 
     /* New status and rate requested by the interface */
     int                     i_new_status, i_new_rate;
@@ -236,6 +285,8 @@ typedef struct input_thread_s
     void                 (* pf_delete_pes)( void *, struct pes_packet_s * );
 
     /* Stream control capabilities */
+    int                  (* pf_set_area)( struct input_thread_s *,
+                                          struct input_area_s * );
     int                  (* pf_rewind)( struct input_thread_s * );
                                            /* NULL if we don't support going *
                                             * backwards (it's gonna be fun)  */
@@ -245,6 +296,8 @@ typedef struct input_thread_s
     char *                  p_source;
 
     int                     i_handle;           /* socket or file descriptor */
+    int                     i_read_once;        /* number of packet read by
+                                                 * pf_read once */
     void *                  p_method_data;     /* data of the packet manager */
     void *                  p_plugin_data;             /* data of the plugin */
 
@@ -264,35 +317,20 @@ typedef struct input_thread_s
 #endif
 } input_thread_t;
 
-
-/*
- * Communication interface -> input
- */
-
-/*****************************************************************************
- * input_config_t
- *****************************************************************************
- * This structure is given by the interface to an input thread
- *****************************************************************************/
-typedef struct input_config_s
-{
-    /* Input method description */
-    int                         i_method;                    /* input method */
-    char *                      p_source;                          /* source */
-
-    /* For auto-launch of decoders */
-    struct aout_thread_s *      p_default_aout;
-    struct vout_thread_s *      p_default_vout;
-} input_config_t;
-
 /* Input methods */
-#define INPUT_METHOD_NONE           0            /* input thread is inactive */
-#define INPUT_METHOD_FILE          10   /* stream is read from file p_source */
-#define INPUT_METHOD_DVD           11      /* stream is read from dvd device */
-#define INPUT_METHOD_UCAST         20                         /* UDP unicast */
-#define INPUT_METHOD_MCAST         21                       /* UDP multicast */
-#define INPUT_METHOD_BCAST         22                       /* UDP broadcast */
-#define INPUT_METHOD_VLAN_BCAST    32            /* UDP broadcast with VLANs */
+/* The first figure is a general method that can be used in interface plugins ;
+ * The second figure is a detailed sub-method */
+#define INPUT_METHOD_NONE         0x0            /* input thread is inactive */
+#define INPUT_METHOD_FILE        0x10   /* stream is read from file p_source */
+#define INPUT_METHOD_DISC        0x20   /* stream is read directly from disc */
+#define INPUT_METHOD_DVD         0x21             /* stream is read from DVD */
+#define INPUT_METHOD_VCD         0x22             /* stream is read from VCD */
+#define INPUT_METHOD_NETWORK     0x30         /* stream is read from network */
+#define INPUT_METHOD_UCAST       0x31                         /* UDP unicast */
+#define INPUT_METHOD_MCAST       0x32                       /* UDP multicast */
+#define INPUT_METHOD_BCAST       0x33                       /* UDP broadcast */
+#define INPUT_METHOD_VLAN_BCAST  0x34            /* UDP broadcast with VLANs */
+
 
 /* Status changing methods */
 #define INPUT_STATUS_END            0
@@ -311,4 +349,9 @@ void input_DestroyThread( struct input_thread_s *, int *pi_status );
 void input_SetStatus( struct input_thread_s *, int );
 void input_SetRate  ( struct input_thread_s *, int );
 void input_Seek     ( struct input_thread_s *, off_t );
-
+void input_DumpStream( struct input_thread_s * );
+char * input_OffsetToTime( struct input_thread_s *, char * psz_buffer, off_t );
+int  input_ChangeES ( struct input_thread_s *, struct es_descriptor_s *, u8 );
+int  input_ToggleES ( struct input_thread_s *,
+                      struct es_descriptor_s *,
+                      boolean_t );
