@@ -2,7 +2,7 @@
  * dvd_ifo.h: Structures for ifo parsing
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: dvd_ifo.h,v 1.11 2001/04/08 07:24:47 stef Exp $
+ * $Id: dvd_ifo.h,v 1.14 2001/04/22 00:08:25 stef Exp $
  *
  * Author: Stphane Borel <stef@via.ecp.fr>
  *
@@ -99,9 +99,13 @@ typedef struct command_s
     u16             i_post_command_nb;              // 2 bytes
     u16             i_cell_command_nb;              // 2 bytes
 //    char[2]         ???
-    command_desc_t* p_pre_command;                  // i_pre_com_nb * 8 bytes
-    command_desc_t* p_post_command;                 // i_post_com_nb * 8 bytes
-    command_desc_t* p_cell_command;                 // i_cell_com_nb * 8 bytes
+    u64* p_pre_command;                  // i_pre_com_nb * 8 bytes
+    u64* p_post_command;                 // i_post_com_nb * 8 bytes
+    u64* p_cell_command;                  // i_pre_com_nb * 8 bytes
+
+//    command_desc_t* p_cell_command;                 // i_cell_com_nb * 8 bytes
+//    command_desc_t* p_post_command;                 // i_post_com_nb * 8 bytes
+//    command_desc_t* p_cell_command;                 // i_cell_com_nb * 8 bytes
 } command_t;
 
 /* Program Chain Map Table
@@ -178,7 +182,7 @@ typedef struct title_s
 /* Menu PGCI Language unit Descriptor */
 typedef struct unit_s
 {
-    char            ps_lang_code[2];            // 2 bytes (ISO-xx)
+    u16             i_lang_code;            // 2 bytes (ISO-xx)
 //    char            ???
     u8              i_existence_mask;           // 1 byte
     u32             i_unit_inf_start_byte;                 // 4 bytes
@@ -455,8 +459,8 @@ typedef struct vts_manager_s
  * we have a pointer to this structure for each tts */
 typedef struct title_start_s
 {
-    u16             i_program_chain_num;                   // 2 bytes; Chapters/PGs
-    u16             i_program_num;                   // 2 bytes
+    u16             i_title_id;         // 2 bytes; Chapters/PGs
+    u16             i_chapter;                   // 2 bytes
 } title_start_t;
 
 /* Main struct for tts
