@@ -2,7 +2,7 @@
  * vout_sdl.c: SDL video output display method
  *****************************************************************************
  * Copyright (C) 1998, 1999, 2000 VideoLAN
- * $Id: vout_sdl.c,v 1.46 2001/04/06 09:15:47 sam Exp $
+ * $Id: vout_sdl.c,v 1.48 2001/04/28 03:36:25 sam Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *          Pierre Baillet <oct@zoy.org>
@@ -52,6 +52,7 @@
 /* FIXME: get rid of this */
 #include "keystrokes.h"
 #include "main.h"
+#include "netutils.h"
 
 /*****************************************************************************
  * FIXME: this file is ...                                                   *
@@ -157,8 +158,12 @@ static int vout_Create( vout_thread_t *p_vout )
     }
 
     /* Initialize library */
-    if( SDL_Init(SDL_INIT_VIDEO | SDL_INIT_EVENTTHREAD | SDL_INIT_NOPARACHUTE)
-            < 0 )
+    if( SDL_Init( SDL_INIT_VIDEO
+#ifndef WIN32
+    /* Win32 SDL implementation doesn't support SDL_INIT_EVENTTHREAD yet*/
+                | SDL_INIT_EVENTTHREAD
+#endif
+	        | SDL_INIT_NOPARACHUTE ) < 0 )
     {
         intf_ErrMsg( "vout error: can't initialize SDL (%s)", SDL_GetError() );
         free( p_vout->p_sys );
@@ -274,7 +279,7 @@ static void vout_Destroy( vout_thread_t *p_vout )
 static int vout_Manage( vout_thread_t *p_vout )
 {
     SDL_Event event;                                            /* SDL event */
-    Uint8     i_key;
+    char *    p_key;
 
     /* Process events */
     while( SDL_PollEvent(&event) )
@@ -326,9 +331,8 @@ static int vout_Manage( vout_thread_t *p_vout )
             break;
 
         case SDL_KEYDOWN:                             /* if a key is pressed */
-            i_key = event.key.keysym.sym;
 
-            switch( i_key )
+            switch( event.key.keysym.sym )
             {
             case SDLK_f:                             /* switch to fullscreen */
                 p_vout->i_changes |= VOUT_FULLSCREEN_CHANGE;
@@ -357,11 +361,51 @@ static int vout_Manage( vout_thread_t *p_vout )
                 p_vout->b_interface = ! p_vout->b_interface;
                 p_vout->i_changes |= VOUT_INTF_CHANGE;
                 break;
+            
+            case SDLK_F10:
+                network_ChannelJoin( 0 );
+                break;
+            case SDLK_F1:
+                network_ChannelJoin( 1 );
+                break;
+            case SDLK_F2:
+                network_ChannelJoin( 2 );
+                break;
+            case SDLK_F3:
+                network_ChannelJoin( 3 );
+                break;
+            case SDLK_F4:
+                network_ChannelJoin( 4 );
+                break;
+            case SDLK_F5:
+                network_ChannelJoin( 5 );
+                break;
+            case SDLK_F6:
+                network_ChannelJoin( 6 );
+                break;
+            case SDLK_F7:
+                network_ChannelJoin( 7 );
+                break;
+            case SDLK_F8:
+                network_ChannelJoin( 8 );
+                break;
+            case SDLK_F9:
+                network_ChannelJoin( 9 );
+                break;
 
+            case SDLK_MENU:
+                p_main->p_intf->b_menu_change = 1;
+                break;
+                
             default:
-                if( intf_ProcessKey( p_main->p_intf, (char )i_key ) )
+                p_key = SDL_GetKeyName( event.key.keysym.sym ) ;
+                if( intf_ProcessKey( p_main->p_intf, 
+                                     (char )event.key.keysym.sym ) )
                 {
-                   intf_DbgMsg( "unhandled key '%c' (%i)", (char)i_key, i_key );                }
+                   intf_DbgMsg( "unhandled key '%c' (%i)", 
+                                (char)event.key.keysym.sym, 
+                                event.key.keysym.sym );                
+                }
                 break;
             }
             break;
